/*
   File: prepare.h
   Prepares the syntax trees for code generation
   - Gathers local names
  
   CVS ID: "$Id: prepare.h,v 1.3 2004/12/26 00:48:47 marcs Exp $"
*/
#ifndef IncPrepare
#define IncPrepare

extern int max_nodenr;
void prepare_grammar ();

#endif /* IncPrepare */
